git.delta.rocks / jrsonnet / refs/commits / 45c49ea21363

difftreelog

feat introduce toplevel-fleet build attribute

xrlvrxmrYaroslav Bolyukin2026-01-22parent: #c653e89.patch.diff
in: trunk

3 files changed

modifiedcmds/fleet/src/cmds/build_systems.rsdiffbeforeafterboth
--- a/modules/nixos/module-list.nix
+++ b/modules/nixos/module-list.nix
@@ -4,4 +4,5 @@
   ./rollback.nix
   ./nix-sign.nix
   ./online.nix
+  ./top-level.nix
 ]
addedmodules/nixos/top-level.nixdiffbeforeafterboth

no content
--- a/cmds/fleet/src/cmds/build_systems.rs
+++ b/cmds/fleet/src/cmds/build_systems.rs
@@ -22,9 +22,9 @@
 
 #[derive(Parser, Clone)]
 pub struct BuildSystems {
 	/// Attribute to build. Systems are deployed from "toplevel" attr, well-known used attributes
 	/// are "sdImage"/"isoImage", and your configuration may include any other build attributes.
-	#[clap(long, default_value = "toplevel")]
+	#[clap(long, default_value = "toplevel-fleet")]
 	build_attr: String,
 }
 
@@ -114,7 +114,7 @@
 
 			set.spawn_local(
 				(async move {
-					let built = match build_task(config.clone(), hostname.clone(), "toplevel").await
+					let built = match build_task(config.clone(), hostname.clone(), "toplevel-fleet").await
 					{
 						Ok(path) => path,
 						Err(e) => {
@@ -22,9 +22,9 @@
 #[derive(Parser, Clone)]
 pub struct BuildSystems {
-	/// Attribute to build. Systems are deployed from "toplevel" attr, well-known used attributes
+	/// Attribute to build. Systems are deployed from "toplevel-fleet" attr, well-known used attributes
 	/// are "sdImage"/"isoImage", and your configuration may include any other build attributes.
modifiedmodules/nixos/module-list.nixdiffbeforeafterboth